package util
{

	import flash.display.DisplayObject;
	import flash.events.Event;
	import flash.events.FocusEvent;
	
	import mx.collections.ICollectionView;
	import mx.containers.VBox;
	import mx.controls.AdvancedDataGrid;
	import mx.controls.Spacer;
	import mx.controls.TextInput;
	import mx.controls.advancedDataGridClasses.AdvancedDataGridColumn;
	import mx.controls.advancedDataGridClasses.AdvancedDataGridHeaderRenderer;
	import mx.controls.advancedDataGridClasses.AdvancedDataGridListData;
	import mx.controls.advancedDataGridClasses.AdvancedDataGridSortItemRenderer;
	import mx.events.CollectionEvent;
	
	/**
	 * AdvancedDataGridHeaderRenderer which include a TextInput filter
	 */
	public class AdvancedDataGridHeaderFilterRenderer extends AdvancedDataGridHeaderRenderer {
	
		/**
		 *   Container of the filter text input. 
		 */
		private var vBox:VBox ;
		
		/**
		 *   Text Input used to Filter the Grid 
		 */		
		private var filterTxt:TextInput ;	
		
		/**
		 * Temporary field to hold 'sortable' property of the AdvancedDataGridColumn. 
		 */
		private var _sortable:Boolean ;
		
		private var _isFirst:Boolean = true ;
		
		private var _sortItemRendererInstance:Object ;

		/**
		 * Default Constructor
		 */
		public function AdvancedDataGridHeaderFilterRenderer() {
			
			super();
			
			filterTxt = new TextInput() ;
			filterTxt.percentWidth = 100 ;			
									
			vBox = new VBox() ;			
			vBox.styleName = this.styleName ;
			vBox.setStyle("horizontalAlign","center") ;
			
			filterTxt.addEventListener(Event.CHANGE,changeHandler) ;
			filterTxt.addEventListener(FocusEvent.FOCUS_IN,onFocusIn) ;
			filterTxt.addEventListener(FocusEvent.FOCUS_OUT,onFocusOut) ;
			
		}
		
		private function onDataProviderChange(event:CollectionEvent):void {			
			clearFilters() ;		
		}
		
		private function clearFilters():void {
			var columnFilters:Object = adg.data ;           	
			for(var colName:String in columnFilters) {				
				var intdex:int = colName.indexOf('filter_') ; 
				if( intdex != -1 ) {							
					adg.data[colName] = null ;
				}						 
			}
		}
		
		private function initDG():void {
			if( _isFirst ) {
				_isFirst = false ;
				initSortItemRendererInstance() ;				
				adg.addEventListener(CollectionEvent.COLLECTION_CHANGE,onDataProviderChange) ;
				
			}
		}	
		
		private function initSortItemRendererInstance():void {
			var temp:Object = null ;
			for(var index:int = 0 ; index < numChildren ; index++) {
				temp = getChildAt(index) ;
				if( temp is AdvancedDataGridSortItemRenderer ) {
					_sortItemRendererInstance = temp ;					
				}
			}
		}
		
		/**
		 * When the filter Text input gets focus we need to make Column unsortable.
		 * Othrwiese, Focus will move out of the text input ( Because of sorting ). 
		 * because of this, we can not type the text properly
		 */
		private function onFocusIn(event:FocusEvent):void {
			_sortable = (data as AdvancedDataGridColumn).sortable ;
			(data as AdvancedDataGridColumn).sortable = false ;
		}
		
		
		/**
		 * When the filter Text input loses its focus, 
		 * We need to restore the 'sortable' value to the Column
		 */
		private function onFocusOut(event:FocusEvent):void {
			(data as AdvancedDataGridColumn).sortable = _sortable ;			
		}
		
		/**
		 * Overridden to include filter text.
		 * Also, label component is removed from the Header and added to filter vBox.
		 * So that, Styles of the Header does not get affected.
		 */
		override protected function createChildren():void {		
			super.createChildren();					
			addChild(vBox);								
			//label.text = label.text + " -C- " + label.y.toString();
			//label.y = 1;
			var spa:mx.controls.Spacer = new mx.controls.Spacer();
			spa.percentWidth = 100;
			spa.percentHeight = 100;
					
			removeChild(label as DisplayObject);				
			vBox.addChild(label as DisplayObject);
			vBox.addChild(spa);
			vBox.addChild(filterTxt);
			vBox.setStyle("horizontalAlign","center");
		}
		
		/**
		 * used to align the contents 
		 */ 
		private function sizeRenderer():void {
			
			initDG() ;
			 
			label.y -= ( filterTxt.height / 2 );
			//label.text = label.text + " -R- " + label.y.toString();
			//label.y = 1;
			//label.x = 2;
			vBox.setStyle("horizontalAlign","center");
			vBox.setActualSize( getExplicitOrMeasuredWidth() ,vBox.getExplicitOrMeasuredHeight()) ;
			
			measuredHeight = measuredMinHeight = vBox.getExplicitOrMeasuredHeight() ;
			measuredWidth = measuredMinWidth = vBox.getExplicitOrMeasuredWidth()  ;
			
			filterTxt.width = (data as AdvancedDataGridColumn).width  ;
			
			if(_sortItemRendererInstance) {
				_sortItemRendererInstance.setStyle("paddingBottom",filterTxt.height) ;
			}
		}
		
		override protected function measure():void {		
			super.measure() ;			
			sizeRenderer() ;
		} 
		
		override protected function updateDisplayList(unscaledWidth:Number,unscaledHeight:Number):void {		
			super.updateDisplayList(unscaledWidth,unscaledHeight) ;						
			sizeRenderer();		
			filterTxt.text = getFilterValue() ;
		}

		/**
		 * Filters the Grid when text input changes
		 */
		private function changeHandler(event:Event):void {			
					
			if(adg)	{								
				saveFilterValue() ;				
				if ( ICollectionView(adg.dataProvider).filterFunction !=  filterFunc ) {
					ICollectionView(adg.dataProvider).filterFunction = filterFunc;					
				}
				ICollectionView(adg.dataProvider).refresh();				
				callLater(setFocusText);				
			}			
		}
		
		
		
		/**
		 * gets the Data Grid of this Column Header
		 */
		private function get adg():AdvancedDataGrid {
			return owner as AdvancedDataGrid ;
		}
		
		/**
		 * Save the filter value to the 'data' property of DataGrid
		 */
		private function saveFilterValue():void {
			if( adg.data == null ) {
				adg.data = new Object() ;
			} 
			adg.data['filter_' + AdvancedDataGridListData(listData).dataField] = filterTxt.text ;
		}
		
		
		/**
		 * gets the filter value
		 */
		private function getFilterValue():String {
			var str:String = '' ;			
			if( adg 
				&& adg.data  
				&& adg.data['filter_' + AdvancedDataGridListData(listData).dataField] ) {
				str = adg.data['filter_' + AdvancedDataGridListData(listData).dataField].toString()
			}			
			return str ;
		}
		
		/**
		 * To set the focus back to the text input
		 */
		private function setFocusText():void {			
			filterTxt.setFocus() ;
		}
		
		/**
		 * Filter Function for the Grid
		 */
		public function filterFunc(rowData:Object):Boolean {		
			if(adg)	{
				if( adg.data ) {	
					var compareVal:Object = null ;			
					for(var colName:String in adg.data) {						
						var intdex:int = colName.indexOf('filter_') ; 
						if( intdex != -1 ) {							
							compareVal = rowData[colName.substring(7,colName.length)].toString();
							if( compareVal is String ) {
								if (  compareVal 
										&& adg.data[colName]
										&& compareVal.toString().toLowerCase().indexOf(adg.data[colName].toString().toLowerCase()) == -1  ) {											
									return false ;																				
								}
							}						
						}					 
					}
				}			
			}           		
			return true;
       }
	
	}

}

 