
CREATE TABLE [dbo].[Empresa] (
	[ID_Empresa] [int] IDENTITY (1, 1) NOT NULL ,
	[CNPJ] [varchar] (20) NULL ,
	[RazaoSocial] [varchar] (255) NOT NULL ,
	[Apelido] [varchar] (50) NOT NULL ,
	[Endereco] [varchar] (255) NULL ,
	[Bairro] [varchar] (100) NULL ,
	[Cidade] [varchar] (100) NULL ,
	[UF] [char] (2) NULL ,
	[CEP] [varchar] (20) NULL ,
	[Complemento] [varchar] (255) NULL ,
	[HomePage] [varchar] (100) NULL ,
	[Email] [varchar] (100) NULL ,
	[Ativo] [bit] NULL,
	CONSTRAINT [PK_Empresa] Primary Key(ID_Empresa)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Filial] 
	(
	[ID_Filial] [int] IDENTITY (1, 1) NOT NULL ,
	[Filial] [varchar] (50) NOT NULL ,
	[ID_Empresa] [int] NOT NULL,
	CONSTRAINT [PK_Filial] Primary Key(ID_Filial),
	CONSTRAINT [FK_Filial_Empresa] Foreign Key(ID_Empresa) REFERENCES Empresa(ID_Empresa) 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Departamento] 
	(
	[ID_Departamento] [int] IDENTITY (1, 1) NOT NULL ,
	[Departamento] [varchar] (50) NOT NULL ,
	[ID_Filial] [int] NOT NULL,
	CONSTRAINT [PK_Departamento] Primary Key(ID_Departamento),
	CONSTRAINT [FK_Departamento_Filial] Foreign Key(ID_Filial) REFERENCES Filial(ID_Filial) 
) ON [PRIMARY]
GO



CREATE TABLE [dbo].[Usuario] 
	(
	[ID_Usuario] [int] IDENTITY (1, 1) NOT NULL ,
	[Login] [varchar] (50) NOT NULL ,
	[Senha] [varchar] (20) NOT NULL ,
	[Nome] [varchar] (150) NOT NULL ,
	[DataNascimento] [datetime] NULL ,
	[Celular] [varchar] (11) NULL ,
	[Telefone] [varchar] (11) NULL ,
	[Email] [varchar] (11) NULL ,
	[RG] [char] (14) NULL ,
	[ID_Departamento] [int] NOT NULL ,
	CONSTRAINT [PK_Usuario] Primary Key(ID_Usuario) ,
	CONSTRAINT [FK_Usuario_Departamento] Foreign Key(ID_Departamento) REFERENCES Departamento(ID_Departamento) 
) ON [PRIMARY]
GO


CREATE TABLE [dbo].[Perfil] 
	(
	[ID_Perfil] [int] IDENTITY (1, 1) NOT NULL ,
	[Titulo] [varchar] (100) NOT NULL ,
	[Descricao] [varchar] (250) NULL ,
	[Status] [bit] NULL ,
	CONSTRAINT [PK_Perfil] Primary Key(ID_Perfil) 
) ON [PRIMARY]
GO


CREATE TABLE [dbo].[UsuarioPerfil] 
	(
	[ID_Usuario] [int] NOT NULL ,
	[ID_Perfil] [int] NOT NULL ,
	CONSTRAINT [FK_UsuarioPerfil_Usuario] Foreign Key(ID_Usuario) REFERENCES Usuario(ID_Usuario) ,
	CONSTRAINT [FK_UsuarioPerfil_Perfil] Foreign Key(ID_Perfil) REFERENCES Perfil(ID_Perfil)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Transacao] 
	(
	[ID_Transacao] [int] IDENTITY (1, 1) NOT NULL ,
	[Titulo] [varchar] (100) NOT NULL ,
	[Descricao] [varchar] (250) NULL ,
	[Status] [bit] NULL ,
	CONSTRAINT [PK_Transacao] Primary Key(ID_Transacao) 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TransacaoPerfil] 
	(
	[ID_Perfil] [int] NOT NULL ,
	[ID_Transacao] [int] NOT NULL ,
	[Consulta] [bit] NULL ,
	[Inclusao] [bit] NULL ,
	[Alteracao] [bit] NULL ,
	[Exclusao] [bit] NULL ,
	[Bloqueio] [bit] NULL ,
	CONSTRAINT [FK_TransacaoPerfil_Perfil] Foreign Key(ID_Perfil) REFERENCES Perfil(ID_Perfil) ,
	CONSTRAINT [FK_TransacaoPerfil_Transacao] Foreign Key(ID_Transacao) REFERENCES Transacao(ID_Transacao)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Fornecedor]  (
	[ID_Fornecedor] [int] IDENTITY (1, 1) NOT NULL ,
	[CNPJ] [varchar] (20) NULL ,
	[RazaoSocial] [varchar] (255) NOT NULL ,
	[Apelido] [varchar] (50) NOT NULL ,
	[Endereco] [varchar] (255) NULL ,
	[Bairro] [varchar] (100) NULL ,
	[Cidade] [varchar] (100) NULL ,
	[UF] [char] (2) NULL ,
	[CEP] [varchar] (20) NULL ,
	[Complemento] [varchar] (255) NULL ,
	[HomePage] [varchar] (100) NULL ,
	[Email] [varchar] (100) NULL ,
	[Ativo] [bit] NULL,
	CONSTRAINT [PK_Fornecedor] Primary Key(ID_Fornecedor)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TipoIC] 
	(
	[ID_TipoIC] [int] IDENTITY (1, 1) NOT NULL ,
	[Descricao] [varchar] (50) NOT NULL ,
	[Observacoes] [varchar] (250) NULL ,
	CONSTRAINT [PK_TipoIC] Primary Key(ID_TipoIC)
) ON [PRIMARY]
GO


CREATE TABLE [IC] 
	(
	[ID_IC] [int] IDENTITY (1, 1) NOT NULL ,
	[Descricao] [varchar] (50) NOT NULL ,
	[IP] [char] (15) NOT NULL ,
	[Status] [int] NOT NULL ,
	[Monitorar] [bit] NULL ,
	[ID_TipoIC] [int] NOT NULL,
	[ID_Departamento] [int] NOT NULL,
	[ID_ICPai] [int] NOT NULL,
	[ID_Fornecedor] [int] NULL,
	CONSTRAINT [PK_IC] Primary Key(ID_IC),
	CONSTRAINT [FK_IC_TipoIC] Foreign Key(ID_TipoIC) REFERENCES TipoIC(ID_TipoIC) ,
	CONSTRAINT [FK_IC_Departamento] Foreign Key(ID_Departamento) REFERENCES Departamento(ID_Departamento),
	CONSTRAINT [FK_IC_ICPai] Foreign Key(ID_ICPai) REFERENCES IC(ID_IC),
	CONSTRAINT [FK_IC_Fornecedor] Foreign Key(ID_Fornecedor) REFERENCES Fornecedor(ID_Fornecedor)
) ON [PRIMARY]
GO


/*
TipoRelacionamento:
0 - O IC  parte de outro IC
1 - O IC  conectado a outro IC
2 - O IC usa outro IC
3 - O IC  filho lgico de outro IC
*/

CREATE TABLE [dbo].[RelacionamentoIC] 
	(
	[ID_RelacionamentoIC] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_ICPai] [int] NOT NULL,
	[ID_ICFilho] [int] NOT NULL,
	[Descricao] [varchar] (200) NULL ,
	[TipoRelacionamento] [int] NOT NULL ,
	CONSTRAINT [PK_RelacionamentoIC] Primary Key(ID_RelacionamentoIC),
	CONSTRAINT [FK_RelacionamentoIC_ICPai] Foreign Key(ID_ICPai) REFERENCES IC(ID_IC) ,
	CONSTRAINT [FK_RelacionamentoIC_ICFilho] Foreign Key(ID_ICFilho) REFERENCES IC(ID_IC)
) ON [PRIMARY]
GO


CREATE TABLE [dbo].[TipoICAtributo] 
	(
	[ID_TipoICAtributo] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_TipoIC] [int] NOT NULL,
	[Grupo] [varchar] (50) NOT NULL ,
	[Descricao] [varchar] (50) NOT NULL ,
	[Observacoes] [varchar] (250) NULL ,
	[Unidade] [int] NOT NULL ,
	[TipoCampo] [int] NOT NULL ,
	[PermiteNull] [bit] NOT NULL ,
	[TamanhoMaximo] [int] NOT NULL ,
	CONSTRAINT [PK_TipoICAtributo] Primary Key(ID_TipoICAtributo),
	CONSTRAINT [FK_TipoICAtributo_TipoIC] Foreign Key(ID_TipoIC) REFERENCES TipoIC(ID_TipoIC)
) ON [PRIMARY]
GO
/*
TipoCampo:
0 - texto
1 - numerico
2 - lista
3 - bit
4 - texto longo
*/

CREATE TABLE [dbo].[TipoICAtributoItem] 
	(
	[ID_TipoICAtributoItem] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_TipoICAtributo] [int] NOT NULL,
	[Codigo] [int] NOT NULL ,
	[Descricao] [varchar] (100) NOT NULL ,
	[Observacoes] [varchar] (250) NULL ,
	[Ordem] [int],
	CONSTRAINT [PK_TipoICAtributoItem] Primary Key(ID_TipoICAtributoItem),
	CONSTRAINT [FK_TipoICAtributoItem_TipoICAtributo] Foreign Key(ID_TipoICAtributo) REFERENCES TipoICAtributo(ID_TipoICAtributo)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[ICAtributo] 
	(
	[ID_ICAtributo] [int] IDENTITY (1, 1) NOT NULL ,
	[Valor] [varchar] (250) NOT NULL ,
	[ID_IC] [int] NOT NULL,
	[ID_TipoICAtributo] [int] NOT NULL,
	CONSTRAINT [PK_ICAtributo] Primary Key(ID_ICAtributo),
	CONSTRAINT [FK_ICAtributo_IC] Foreign Key(ID_IC) REFERENCES IC(ID_IC) ,
	CONSTRAINT [FK_ICAtributo_TipoICAtributo] Foreign Key(ID_TipoICAtributo) REFERENCES TipoICAtributo(ID_TipoICAtributo)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[ICAtributoHistorico] 
	(
	[ID_ICAtributo] [int] NOT NULL ,
	[ID_Usuario] [int] NOT NULL ,
	[DataHora] [datetime] NOT NULL,
	[TipoRegistro] [int] NOT NULL,
	[Valor] [varchar] (250) NOT NULL ,
	CONSTRAINT [FK_ICAtributoHistorico_ICAtributo] Foreign Key(ID_ICAtributo) REFERENCES ICAtributo(ID_ICAtributo),
	CONSTRAINT [FK_ICAtributoHistorico_Usuario] Foreign Key(ID_Usuario) REFERENCES Usuario(ID_Usuario)
) ON [PRIMARY]
GO

/*
Gravidade
0 - Informao
1 - baixa
2 - mdia
3 - alta
4 - crtica
*/

CREATE TABLE [dbo].[ConfiguracaoAlerta] 
	(
	[ID_ConfiguracaoAlerta] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_ICAtributo] [int] NOT NULL ,
	[Descricao] [varchar] (100) NOT NULL ,
	[Quando] [int] NOT NULL ,
	[Media] [int] NOT NULL ,
	[Condicao][int] NOT NULL,
	[Valor][varchar] (250) NOT NULL,
	[IntervaloVerificacao] [int] NOT NULL ,
	[DataProximaVerificacao] [datetime] NOT NULL ,
	[EnviaEmail] [bit] NOT NULL ,
	[EnviaMensagem] [bit] NOT NULL ,
	[Gravidade][int] NOT NULL,
	[Ativo] [bit] NULL ,
	CONSTRAINT [PK_ConfiguracaoAlerta] Primary Key(ID_ConfiguracaoAlerta),
	CONSTRAINT [FK_ConfiguracaoAlerta_ICAtributo] Foreign Key(ID_ICAtributo) REFERENCES ICAtributo(ID_ICAtributo)
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Alerta] 
	(
	[ID_Alerta] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_ConfiguracaoAlerta] [int] NOT NULL ,
	[DataAlerta] [datetime] NOT NULL ,
	[Valor] [text] NULL ,
	[Lido] [bit] NULL ,
	[DataCiencia] [datetime] NULL ,
	[ID_Usuario] [int] NULL ,
	CONSTRAINT [PK_Alerta] Primary Key(ID_Alerta),
	CONSTRAINT [FK_Alerta_ConfiguracaoAlerta] Foreign Key(ID_ConfiguracaoAlerta) REFERENCES ConfiguracaoAlerta(ID_ConfiguracaoAlerta),
	CONSTRAINT [FK_Alerta_Usuario] Foreign Key(ID_Usuario) REFERENCES Usuario(ID_Usuario),
) ON [PRIMARY]
GO


CREATE TABLE [dbo].[OID] 
	(
	[ID_OID] [int] IDENTITY (1, 1) NOT NULL ,
	[Descricao] [varchar] (200) NOT NULL ,
	[OID] [varchar] (100) NOT NULL,
	CONSTRAINT [PK_OID] Primary Key(ID_OID),
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[ConfiguracaoMonitoramento] 
	(
	[ID_ConfiguracaoMonitoramento] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_ICAtributo] [int] NOT NULL ,
	[ID_OID] [int] NOT NULL ,
	[Descricao] [varchar] (250) NOT NULL ,
	[SequenciaOID] [varchar] (50),
	[TipoRetorno] [int] NOT NULL ,
	[IntervaloVerificacao] [int] NOT NULL ,
	[ColetorResponsavel] [varchar] (100) NOT NULL ,
	[DataProximaVerificacao] [datetime] NOT NULL ,
	[Ativo] [bit] NULL ,
	CONSTRAINT [PK_ConfiguracaoMonitoramento] Primary Key(ID_ConfiguracaoMonitoramento),
	CONSTRAINT [FK_ConfiguracaoMonitoramento_ICAtributo] Foreign Key(ID_ICAtributo) REFERENCES ICAtributo(ID_ICAtributo),
	CONSTRAINT [FK_ConfiguracaoMonitoramento_OID] Foreign Key(ID_OID) REFERENCES OID(ID_OID)
) ON [PRIMARY]
GO


CREATE TABLE [dbo].[Relatorio] 
	(
	[ID_Relatorio] [int] IDENTITY (1, 1) NOT NULL ,
	[Titulo] [varchar] (50) NOT NULL ,
	[Descricao] [varchar] (250) NULL ,
	[Query] [text] NOT NULL ,
	CONSTRAINT [PK_Relatorio] Primary Key(ID_Relatorio) 
) ON [PRIMARY]
GO
 
CREATE TABLE [dbo].[Controle] 
	(
	[ID_Controle] [int] IDENTITY (1, 1) NOT NULL ,
	[Descricao] [varchar] (100) NOT NULL ,
	[TabelaDescricao] [varchar] (100) NOT NULL ,
	[QueryDescricao] [varchar] (300) NOT NULL ,
	CONSTRAINT [PK_Controle] Primary Key(ID_Controle) 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Campo] 
	(
	[ID_Campo] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_controle] [int] NOT NULL ,
	[Descricao] [varchar] (100) NOT NULL ,
	CONSTRAINT [PK_Campo] Primary Key(ID_Campo) ,
	CONSTRAINT [FK_Campo_Controle] Foreign Key(ID_Controle) REFERENCES Controle(ID_Controle) 	
) ON [PRIMARY]
GO 

CREATE TABLE [dbo].[TrilhaAuditoria] 
	(
	[ID_TrilhaAuditoria] [int] IDENTITY (1, 1) NOT NULL ,
	[ID_Campo] [int] NOT NULL ,
	[ID_Usuario] [int] NOT NULL ,
	[IDAlterado] [int] NOT NULL ,
	[DataHoraAlteracao] [datetime] NOT NULL ,
	[ValorAnterior] [varchar] (1000) NOT NULL ,
	[ValorNovo] [varchar] (1000) NOT NULL ,
	[TipoLog] [int] NOT NULL ,
	CONSTRAINT [PK_TrilhaAuditoria] Primary Key(ID_TrilhaAuditoria) , 
	CONSTRAINT [FK_TrilhaAuditoria_Campo] Foreign Key(ID_Campo) REFERENCES Campo(ID_Campo) ,
	CONSTRAINT [FK_TrilhaAuditoria_Usuario] Foreign Key(ID_Usuario) REFERENCES Usuario(ID_Usuario)
) ON [PRIMARY]
GO 

SET IDENTITY_INSERT [dbo].[Controle] ON
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (1, N'Empresa', N'Empresa', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (2, N'Filial', N'Filial', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (3, N'Fornecedor', N'Fornecedor', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (4, N'TipoIC', N'TipoIC', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (5, N'IC', N'IC', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (6, N'Departamento', N'Departamento', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (7, N'ICAtributo', N'ICAtributo', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (8, N'TipoICAtributoEstado', N'TipoICAtributoEstado', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (9, N'TipoICAtributo', N'TipoICAtributo', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (10, N'Usuario', N'Usuario', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (11, N'Perfil', N'Perfil', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (12, N'ConfiguracaoAlerta', N'ConfiguracaoAlerta', N'Descricao')
INSERT [dbo].[Controle] ([ID_Controle], [Descricao], [TabelaDescricao], [QueryDescricao]) VALUES (13, N'ConfiguracaoMonitoramento', N'ConfiguracaoMonitoramento', N'Descricao')
SET IDENTITY_INSERT [dbo].[Controle] OFF


